SAVEE (Surrey Audio-Visual Expressed Emotion) is an emotion recognition dataset.
It consists of recordings from 4 male actors in 7 different emotions, 480
British English utterances in total. The sentences were chosen from the standard
TIMIT corpus and phonetically-balanced for each emotion. This release contains
only the audio stream from the original audio-visual recording.

The data is split so that the training set consists of 2 speakers, and both the
validation and test set consists of samples from 1 speaker, respectively.
